==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPicker.java <==
// java wrapper for vtkPicker object
//

package vtk;
import vtk.*;

public class vtkPicker extends vtkAbstractPropPicker
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetTolerance_2(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_2(id0); }

  private native double GetTolerance_3();
  public double GetTolerance()
    { return GetTolerance_3(); }

  private native double[] GetMapperPosition_4();
  public double[] GetMapperPosition()
    { return GetMapperPosition_4(); }

  private native long GetMapper_5();
  public vtkAbstractMapper3D GetMapper() {
    long temp = GetMapper_5();

    if (temp == 0) return null;
    return (vtkAbstractMapper3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetDataSet_6();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetProp3Ds_7();
  public vtkProp3DCollection GetProp3Ds() {
    long temp = GetProp3Ds_7();

    if (temp == 0) return null;
    return (vtkProp3DCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetActors_8();
  public vtkActorCollection GetActors() {
    long temp = GetActors_8();

    if (temp == 0) return null;
    return (vtkActorCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPickedPositions_9();
  public vtkPoints GetPickedPositions() {
    long temp = GetPickedPositions_9();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int Pick_10(double id0,double id1,double id2,vtkRenderer id3);
  public int Pick(double id0,double id1,double id2,vtkRenderer id3)
    { return Pick_10(id0,id1,id2,id3); }

  private native int Pick_11(double id0[],vtkRenderer id1);
  public int Pick(double id0[],vtkRenderer id1)
    { return Pick_11(id0,id1); }

  public vtkPicker() { super(); }

  public vtkPicker(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkPicker.java <==
// java wrapper for vtkPicker object
//

package vtk;
import vtk.*;

public class vtkPicker extends vtkAbstractPropPicker
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetTolerance_2(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_2(id0); }

  private native double GetTolerance_3();
  public double GetTolerance()
    { return GetTolerance_3(); }

  private native double[] GetMapperPosition_4();
  public double[] GetMapperPosition()
    { return GetMapperPosition_4(); }

  private native long GetMapper_5();
  public vtkAbstractMapper3D GetMapper() {
    long temp = GetMapper_5();

    if (temp == 0) return null;
    return (vtkAbstractMapper3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetDataSet_6();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCompositeDataSet_7();
  public vtkCompositeDataSet GetCompositeDataSet() {
    long temp = GetCompositeDataSet_7();

    if (temp == 0) return null;
    return (vtkCompositeDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetFlatBlockIndex_8();
  public int GetFlatBlockIndex()
    { return GetFlatBlockIndex_8(); }

  private native long GetProp3Ds_9();
  public vtkProp3DCollection GetProp3Ds() {
    long temp = GetProp3Ds_9();

    if (temp == 0) return null;
    return (vtkProp3DCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetActors_10();
  public vtkActorCollection GetActors() {
    long temp = GetActors_10();

    if (temp == 0) return null;
    return (vtkActorCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPickedPositions_11();
  public vtkPoints GetPickedPositions() {
    long temp = GetPickedPositions_11();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int Pick_12(double id0,double id1,double id2,vtkRenderer id3);
  public int Pick(double id0,double id1,double id2,vtkRenderer id3)
    { return Pick_12(id0,id1,id2,id3); }

  private native int Pick_13(double id0[],vtkRenderer id1);
  public int Pick(double id0[],vtkRenderer id1)
    { return Pick_13(id0,id1); }

  public vtkPicker() { super(); }

  public vtkPicker(long id) { super(id); }
  public native long   VTKInit();

}
